chromium_pickle library

Classes

Pickle
Class that provides facilities for basic packing and unpacking of binary values.
PickleIterator
Class that used to read data from Pickle objects.

Enums

PickleConstants
Pickle constants.
PickleSize
Sizes of Pickle data types in bytes.

Functions

alignInt(int number, int alignment) int
Aligns number by rounding it up to the next multiple of alignment.